<?php

/**
 * @file
 * Webform module calculation component.
 */

/**
 * Implements _webform_defaults_component().
 */
function _webform_defaults_calculation() {
  return array(
    'name' => '',
    'form_key' => NULL,
    'pid' => 0,
    'weight' => 0,
    'value' => '',
    'extra' => array(
      'format' => NULL,
      'private' => FALSE,
    ),
  );
}

/**
 * Implements _webform_theme_component().
 */
function _webform_theme_calculation() {
  return array(
    'webform_display_calculation' => array(
      'render element' => 'element',
      'file' => 'components/calculation.inc',
      'path' => drupal_get_path('module', 'webform_calculation_field'),
    ),
  );
}

/**
 * Implements _webform_edit_component().
 */
function _webform_edit_calculation($component) {
  $form = array();
  $form['value'] = array(
    '#type' => 'textarea',
    '#title' => t('Value'),
    '#default_value' => $component['value'],
    '#description' => t('This field provides ability to specify PHP class instantiation or function name,
      which will handle calculation.<br />
      All webform input fields are available as the variables and can be used as parameters to the constructor or the function.
      If class instantiation was used &mdash; then class object will be available in the template,
      if function name was specified &mdash; then function result will be available in the template.<br />
      Do not use &lt;?php ?&gt; tags, just specify class instantiation or function name (input values can be used as parameters).<br />
      For example:<br />
      <em>new LensCalculator($sphere, $cylinder, $axis, $currentVertex, $newVertex);</em><br />
      in this case instance of the class LensCalculator will be created.<br />
      <em>rand($custom_module_min, $custom_module_max);</em>
      <br />in this case function rand() will be called with specified parameters, webform should contain fields with keys <em>custom_module_min</em> and <em>custom_module_max</em>.
      Result of the function will be available in the template as $result variable.'),
    '#cols' => 60,
    '#rows' => 5,
    '#weight' => -1,
  );

  return $form;
}

/**
 * Implements _webform_render_component().
 */
function _webform_render_calculation($component, $value = NULL, $filter = TRUE) {
  $default_value = $component['value'];
  if (isset($value[0])) {
    $default_value = $value[0];
  }

  $element = array(
    '#type' => 'value',
    '#title' => $filter ? webform_filter_xss($component['name']) : $component['name'],
    '#weight' => $component['weight'],
    '#translatable' => array('title'),
    '#value' => $default_value,
  );

  return $element;
}

/**
 * Implements _webform_display_component().
 */
function _webform_display_calculation($component, $value, $format = 'html') {
  return array(
    '#title' => $component['name'],
    '#markup' => isset($value[0]) ? $value[0] : NULL,
    '#weight' => $component['weight'],
    '#theme' => 'webform_display_calculation',
    '#theme_wrappers' => $format == 'text' ? array('webform_element_text') : array('webform_element'),
    '#format' => $format,
    '#translatable' => array('title'),
  );
}

/**
 * Format the output of data for this component.
 */
function theme_webform_display_calculation($variables) {
  $element = $variables['element'];

  return $element['#format'] == 'html' ? check_plain($element['#markup']) : $element['#markup'];
}
